shell

package
v0.14.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MPL-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package shell provides helpers for executing external commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunShellCommand

func RunShellCommand(workingDir string, envVars []string, command string, args ...string) error

RunShellCommand runs the given shell command with the given environment variables and arguments in the given working directory

func RunShellCommandAndGetOutput

func RunShellCommandAndGetOutput(workingDir string, envVars []string, argslist ...string) (string, error)

RunShellCommandAndGetOutput runs the given shell command with the given environment variables and arguments in the given working directory

func RunShellCommandAndGetOutputWithContext

func RunShellCommandAndGetOutputWithContext(ctx context.Context, workingDir string, envVars []string, argslist ...string) (string, error)

RunShellCommandAndGetOutputWithContext runs the given shell command with the given environment variables and arguments in the given working directory

func RunShellCommandWithContext

func RunShellCommandWithContext(ctx context.Context, workingDir string, envVars []string, command string, args ...string) error

RunShellCommandWithContext runs the given shell command with the given environment variables and arguments in the given working directory

Types

This section is empty.

Jump to