Documentation
¶
Overview ¶
Package shell provides helpers for executing external commands.
Index ¶
- func RunShellCommand(workingDir string, envVars []string, command string, args ...string) error
- func RunShellCommandAndGetOutput(workingDir string, envVars []string, argslist ...string) (string, error)
- func RunShellCommandAndGetOutputWithContext(ctx context.Context, workingDir string, envVars []string, argslist ...string) (string, error)
- func RunShellCommandWithContext(ctx context.Context, workingDir string, envVars []string, command string, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunShellCommand ¶
RunShellCommand runs the given shell command with the given environment variables and arguments in the given working directory
func RunShellCommandAndGetOutput ¶
func RunShellCommandAndGetOutput(workingDir string, envVars []string, argslist ...string) (string, error)
RunShellCommandAndGetOutput runs the given shell command with the given environment variables and arguments in the given working directory
func RunShellCommandAndGetOutputWithContext ¶
func RunShellCommandAndGetOutputWithContext(ctx context.Context, workingDir string, envVars []string, argslist ...string) (string, error)
RunShellCommandAndGetOutputWithContext runs the given shell command with the given environment variables and arguments in the given working directory
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.